from .kaggle_5th_place_model import FootballKaggle5thPlaceModel
from .rule_based_bot_model import FootballRuleBaseModel
